from django.urls import path, include
from rest_framework.routers import DefaultRouter
from .views import (
    ConversationViewSet, MessageViewSet, FeedbackViewSet,
    FeedbackTagViewSet, DetailedFeedbackViewSet, ConversationSubmissionViewSet,
    ConversationEvaluationViewSet, SystemConfigViewSet
)

router = DefaultRouter()
router.register(r'conversations', ConversationViewSet)
router.register(r'messages', MessageViewSet)
router.register(r'feedback', FeedbackViewSet)
router.register(r'feedback-tags', FeedbackTagViewSet)
router.register(r'detailed-feedback', DetailedFeedbackViewSet)
router.register(r'submissions', ConversationSubmissionViewSet)
router.register(r'evaluations', ConversationEvaluationViewSet)
router.register(r'system-config', SystemConfigViewSet)

urlpatterns = [
    path('', include(router.urls)),
    # 额外的RLHF相关API端点
    path('conversation/<str:pk>/messages/', ConversationViewSet.as_view({'get': 'messages'}), name='conversation-messages'),
    path('conversation/<str:pk>/message/', ConversationViewSet.as_view({'post': 'message'}), name='send-message'),
    path('conversation/<str:pk>/submit/', ConversationViewSet.as_view({'post': 'submit'}), name='submit-conversation'),
    path('conversation/<str:pk>/resume/', ConversationViewSet.as_view({'post': 'resume'}), name='resume-conversation'),
    path('submission/<str:pk>/review/', ConversationSubmissionViewSet.as_view({'post': 'review'}), name='review-submission'),
    path('models/', SystemConfigViewSet.as_view({'get': 'models'}), name='models-list'),
    path('model/', SystemConfigViewSet.as_view({'get': 'model', 'post': 'model'}), name='current-model'),
] 